
clear all
close all

% The endogenous divorce model

% Basic parameters
w_m=1;
w_f=.9;

r=.05;

beta=1/(1+r);

lam_f=0.4;
lam_m=1-lam_f;

% Property division rule
kap_f=0.5;
kap_m=1-kap_f;

% Need to solve by backward induction
% Grid for the preference shock

xi_min=-.2;
xi_max=1;
grid_size_xi=40;

xi_grid=linspace(xi_min,xi_max,grid_size_xi);
% Probabilities are all the same for simplicity

grid_size_a=50;

a_min=-0.02;
a_max=0.12;

a_grid=linspace(a_min,a_max,grid_size_a);

% Go through different values of female wages
w_f_grid=linspace(0.1,1,20);

a_opt=zeros(1,20);
sav_opt=zeros(1,20);

div_opt=zeros(1,20);

% Cycle through relative female wage
k=1;
while k<=20
    w_f=w_f_grid(k);

    % Define value functions
    V_f=zeros(grid_size_a,grid_size_xi,grid_size_xi);
    V_m=V_f;
    
    % Reset divorce rate by assets
    div_rate=zeros(1,grid_size_a);
    
    % Compute second-period value function for every state
    i=1;
    while i<=grid_size_a
        
        % Initiate divorce rate
        div=0;
        
        j=1;
        while j<=grid_size_xi
            h=1;
            while h<=grid_size_xi

                a=a_grid(i);
                xi_f=xi_grid(j);
                xi_m=xi_grid(h);

                % Income in the period for marriage and divorce
                I=w_f+w_m+(1+r)*a;
                I_f=w_f+(1+r)*kap_f*a;
                I_m=w_m+(1+r)*kap_m*a;

                if I<0
                    'error'
                    pause
                elseif I_f<0
                    'error'
                    pause
                elseif I_m<0
                    'error'
                    pause
                end

                % Implied indifference weights
                tild_lam_f=I_f/(exp(xi_f)*I);
                tild_lam_m=I_m/(exp(xi_m)*I);

                if (tild_lam_f<=lam_f) & (tild_lam_m<=lam_m)
                    % No divorce, no binding constraints
                    V_f(i,j,h)=log(lam_f*I)+xi_grid(j);
                    V_m(i,j,h)=log(lam_m*I)+xi_grid(h);

                elseif tild_lam_f+tild_lam_m>1
                    % Divorce
                    V_f(i,j,h)=log(I_f);
                    V_m(i,j,h)=log(I_m);
                    
                    div=div+1/grid_size_xi^2;

                elseif tild_lam_f>lam_f
                    % Wife is constrained
                    c_f=I_f/exp(xi_f);
                    c_m=I-c_f;

                    V_f(i,j,h)=log(c_f)+xi_grid(j);
                    V_m(i,j,h)=log(c_m)+xi_grid(h);

                elseif tild_lam_m>lam_m
                    % Husband is constrained
                    c_m=I_m/exp(xi_m);
                    c_f=I-c_m;

                    V_f(i,j,h)=log(c_f)+xi_grid(j);
                    V_m(i,j,h)=log(c_m)+xi_grid(h);

                else

                    'ERROR'

                end


                h=h+1;
            end
            j=j+1;
            
            div_rate(i)=div;
            
        end
        i=i+1;
    end

    % Compute optimal savings in first period

    % Initiate value function
    V=zeros(1,grid_size_a);

    i=1;
    while i<=grid_size_a

        c_f=lam_f*(w_f+w_m-a_grid(i));
        c_m=lam_m*(w_f+w_m-a_grid(i));

        V(i)=lam_f*(log(c_f)+beta*sum(sum(V_f(i,:,:)))/(grid_size_xi^2))...
            +lam_m*(log(c_m)+beta*sum(sum(V_m(i,:,:)))/(grid_size_xi^2));

        
        i=i+1;

    end
    
    [junk a_opt_ind]=max(V);
    a_opt(k)=a_grid(a_opt_ind);
    sav_opt(k)=a_opt(k)/(w_f+w_m);
    
    % Compute divorce rate at optimal savings
    div_opt(k)=div_rate(a_opt_ind);
   
    k=k+1;
    
end



figure
subplot(2,1,1)
gr=plot(w_f_grid,sav_opt,'b-');
hold on
gr2=plot([0.1 1],[0 0],'k:');
ylabel('Savings Rate');
xlabel('Relative Female Earnings');
axis([0.1 .8 -.02 .1]);
set(gr,'LineWidth',2);
hold off

subplot(2,1,2)
gr=plot(w_f_grid,div_opt,'b-');
hold on
ylabel('Divorce Rate');
xlabel('Relative Female Earnings');
axis([0.1 .8 0 .2]);
set(gr,'LineWidth',2);
hold off


% % Do it again with exogenous divorce
% Imposing the probability from the endogenous case

% Cycle through relative female wage
k=1;
while k<=20
    w_f=w_f_grid(k);

    % Define value functions
    % First element is marriage, second divorce
    V_f=zeros(grid_size_a,2);
    V_m=V_f;
    
    % Reset divorce rate by assets
    div_rate=div_opt(k);
    
    % Compute second-period value function for every state
    i=1;
    while i<=grid_size_a
        
        a=a_grid(i);

        % Income in the period for marriage and divorce
        I=w_f+w_m+(1+r)*a;
        I_f=w_f+(1+r)*kap_f*a;
        I_m=w_m+(1+r)*kap_m*a;

        if I<0
            'error'
            pause
        elseif I_f<0
            'error'
            pause
        elseif I_m<0
            'error'
            pause
        end

        
        % No divorce
        V_f(i,1)=log(lam_f*I);
        V_m(i,1)=log(lam_m*I);

        % Divorce
        V_f(i,2)=log(I_f);
        V_m(i,2)=log(I_m);               
        
        i=i+1;
    end

    % Compute optimal savings in first period

    % Initiate value function
    V=zeros(1,grid_size_a);

    i=1;
    while i<=grid_size_a

        c_f=lam_f*(w_f+w_m-a_grid(i));
        c_m=lam_m*(w_f+w_m-a_grid(i));

        V(i)=lam_f*(log(c_f)+beta*((1-div_rate)*V_f(i,1)+div_rate*V_f(i,2)))...
            +lam_m*(log(c_m)+beta*((1-div_rate)*V_m(i,1)+div_rate*V_m(i,2)));

        i=i+1;
        
    end
       
    [junk a_opt_ind]=max(V);
    a_opt(k)=a_grid(a_opt_ind);
    sav_opt_exo(k)=a_opt(k)/(w_f+w_m);
   
    k=k+1;
    
end

    
figure
subplot(2,1,1)
gr=plot(w_f_grid,sav_opt,'b-',w_f_grid,sav_opt_exo,'r--' );
hold on
ll=legend('Endogenous Divorce','Exogenous Divorce','Location','NorthEast');
gr2=plot([0.1 1],[0 0],'k:');
ylabel('Savings Rate');
xlabel('Relative Female Earnings');
axis([0.1 .8 -.02 .1]);
set(gr,'LineWidth',2);
set(ll,'Fontsize',12);
hold off

subplot(2,1,2)
gr=plot(w_f_grid,div_opt,'b-');
hold on
ylabel('Divorce Rate');
xlabel('Relative Female Earnings');
axis([0.1 .8 0 .2]);
set(gr,'LineWidth',2);
hold off

