clear all;
close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
% Figure 20: Fertility Restrictions (Section 3.3 in Paper)              %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% set parameters
A = 10;
B=1;
g = 0.5;
gn = 0.8;
theta = 0.5;
phi = 0.1;
n_bar = (1:0.1:5);
[n m] = size(n_bar);
n_vec = zeros(1,m);
e_vec = zeros(1,m);
U_vec = zeros(1,m);
growth_vec = zeros(1,m);

% star values: unrestricted equilibrium
e_star = g*theta/(gn-g*theta)*phi;
n_star = (gn - g*theta)/(phi*(1+gn));
l_star = 1-(phi+e_star).*n_star;
U_star = log(A*l_star)+gn*log(n_star)+g*theta*log(e_star);
growth_star=(B*e_star).^theta;

% bar values: restricted equilibrium
e_bar = g*theta*(1./n_bar - phi)/(1+g*theta);
l_bar = 1-(phi+e_bar).*n_bar;
U_bar = log(A*l_bar)+gn*log(n_bar)+g*theta*log(e_bar);
growth_bar=(B*e_bar).^theta;


% check when constraint is binding and piece the two solutions together
i = 1;
while i <=m;
if n_star <= n_bar(i);
n_vec(i) = n_star;
e_vec(i) = e_star;
U_vec(i) = U_star;
growth_vec(i)= growth_star;
else
n_vec(i) = n_bar(i);
e_vec(i) = e_bar(i);
U_vec(i) = U_bar(i);
growth_vec(i)= growth_bar(i);
end;
 i = i + 1;
end;


% Plot figure
figure;
subplot(2,2,1);
gr=plot(n_bar,n_vec);
ylabel('Fertility');
xlabel('Fertility Limit');
set(gr,'LineWidth',2);
subplot(2,2,2);
gr2=plot(n_bar,e_vec);
ylabel('Education');
xlabel('Fertility Limit');
set(gr2,'LineWidth',2);
subplot(2,2,3);
gr3=plot(n_bar,growth_vec);
ylabel('Growth Rate');
xlabel('Fertility Limit');
set(gr3,'LineWidth',2);
subplot(2,2,4);
gr4=plot(n_bar,U_vec);
ylabel('Utility');
xlabel('Fertility Limit');
set(gr4,'LineWidth',2);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
% Figure 22: Growth Rate as function of alpha (Section 3.6 in Paper)    %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set parameters

gf = 0.5;
gm = 0.2;
b = 0.7;
B = 10;
theta = 0.5;

avec = (0.05:0.01:0.5)';

% exogenous bargaining

lambda = 0.2;
g = lambda*gf+(1-lambda)*gm;
growth_exog = ((B*g*theta)./(avec+g*theta) .*(1-avec).^(1-b).*(avec).^(b) ).^theta;

labor_vec = avec./(avec+(1-avec)*g*theta + avec*g*theta)
em_vec = ((1-avec)*g*theta)./(avec+(1-avec)*g*theta + avec*g*theta)
ef_vec = (avec*g*theta)./(avec+(1-avec)*g*theta + avec*g*theta)

%figure;
%plot(avec,labor_vec,avec,em_vec,avec,ef_vec);
%legend('female labor','male education','female education');
%title('exogenous bargaining');

% endogenous bargaining

lambda_vec = avec;
g_vec = lambda_vec*gf+(1-lambda_vec)*gm;
growth_endog = ( (B*g_vec*theta)./(avec+g_vec*theta) .*(1-avec).^(1-b).*(avec).^(b) ).^theta;

labor_end_vec = avec./(avec+(1-avec).*g_vec*theta + avec*g*theta)
em_end_vec = ((1-avec).*g_vec*theta)./(avec+(1-avec).*g_vec*theta + avec.*g_vec*theta)
ef_end_vec = (avec.*g_vec*theta)./(avec+(1-avec).*g_vec*theta + avec.*g_vec*theta)

%figure;
%plot(avec,labor_end_vec,avec,em_end_vec,avec,ef_end_vec);
%legend('female labor','male education','female education');
%title('endogenous bargaining');


% Figure used in the paper

figure;
gr=plot(avec,growth_exog,avec,growth_endog,'--');
zz=legend('exogenous bargaining','endogenous bargaining');
hold on;
xx=xlabel('alpha');
yy=ylabel('Growth Rate');
set(xx,'Fontsize',16);
set(yy,'Fontsize',16);
set(zz,'Fontsize',14);
set(gr,'LineWidth',2);



%figure;
%plot(avec,lambda,avec,lambda_vec);
%legend('exogenous','endogenous');
%xlabel('alpha');
%title('bargaining power');




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
% Figure 25: Female Empowerment (Section 4.3 in Paper)                  %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% set parameters

A = 5;
B = 5;
theta = (0:0.05:5)';
gamma_m = 0.3;
gamma_f = 0.9;
gamma_G = 1.2;
lambda_f=0.5;
lambda_m=1-lambda_f;
gamma_E = lambda_m*gamma_m + lambda_f*gamma_f;
H_0 = 10;


% Patriarchy;
e_P = (gamma_m*theta)./(1+gamma_m*theta);
l_P = 2 - 2*e_P;
c_P = A*l_P*H_0;
H_P_1 = (B*e_P).^theta; % children
H_P_2 = (B*e_P).^(theta); % grand-children
U_m_P = log(c_P) + gamma_m*log(H_P_1) + gamma_G*log(H_P_2);

% Empowerment;
e_E = (gamma_E*theta)./(1+gamma_E*theta);
l_E = 2 - 2*e_E;
c_E = 0.5*A*l_E*H_0;
H_E_1 = (B*e_E).^theta; % children
H_E_2 = (B*e_E).^(theta); % grand-children
U_m_E = log(c_E) + gamma_m*log(H_E_1) + gamma_G*log(H_E_2);


% Education & Male Utility
figure;
subplot(2,1,1);
gr=plot(theta,e_P,theta,e_E,'--');
xx=xlabel('theta');
yy=ylabel('Education');
set(xx,'Fontsize',12);
set(yy,'Fontsize',12);
set(gr,'LineWidth',2);

subplot(2,1,2);
gr=plot(theta,U_m_P,theta,U_m_E,'--');
zz=legend('Patriarchy','Empowerment');
hold on;
xx=xlabel('theta');
yy=ylabel('Male Utility');
set(xx,'Fontsize',12);
set(yy,'Fontsize',12);
set(zz,'Fontsize',12);
set(gr,'LineWidth',2);

% % Male Consumption
% figure;
% gr=plot(theta,c_P,theta,c_E,'--');
% zz=legend('Patriarchy','Empowerment');
% xx=xlabel('theta');
% yy=ylabel('Male Consumption');
% set(xx,'Fontsize',16);
% set(yy,'Fontsize',16);
% set(zz,'Fontsize',14);
% set(gr,'LineWidth',2);
% 
% % Market Work
% % Education
% figure;
% gr=plot(theta,l_P,theta,l_E,'--');
% zz=legend('Patriarchy','Empowerment');
% xx=xlabel('theta');
% yy=ylabel('Market Work');
% set(xx,'Fontsize',16);
% set(yy,'Fontsize',16);
% set(zz,'Fontsize',14);
% set(gr,'LineWidth',2);


